#
# spec file for package acl
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           acl
%define lname	libacl1
Summary:        Commands for Manipulating POSIX Access Control Lists
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Filesystems
Version:        2.2.52
Release:        10.15
Url:            http://download.savannah.gnu.org/releases-noredirect/acl/

#Git-Web:	http://git.savannah.gnu.org/cgit/acl.git/
#Git-Clone:	git://git.sv.gnu.org/acl
Source:         http://download.savannah.gnu.org/releases-noredirect/acl/%name-%version.src.tar.gz
Source1:        http://download.savannah.gnu.org/releases-noredirect/acl/%name-%version.src.tar.gz.sig
Source2:        baselibs.conf
# http://savannah.nongnu.org/project/memberlist-gpgkeys.php?group=acl
Source3:        %name.keyring
Patch0:         builddefs.in.diff
Patch2:         0001-Use-OS-byteswapping-macros.patch
Patch3:         libacl-make-sure-that-acl_from_text-always-sets-errno-when-it-fails.patch
Patch4:         libacl-fix-sigsegv-of-getfacl-e-on-overly-long-group-name.patch
Patch5:         read_acl_-comments-seq-rename-line-to-lineno.patch
Patch6:         read_acl_-comments-seq-switch-to-next_line.patch
Patch7:         getfacl-fix-memory-leak.patch
Patch8:         getfacl-fix-minor-resource-leak.patch
BuildRequires:  libattr-devel
#BuildRequires:  gpg-offline
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
getfacl and setfacl commands for retrieving and setting POSIX access
control lists.

%package -n %lname
Summary:        A dynamic library for accessing POSIX Access Control Lists
Group:          System/Libraries
# bug437293
%ifarch ppc64
Obsoletes:      libacl-64bit
%endif
# Added for 12.1
Provides:       libacl = %version-%release
Obsoletes:      libacl < %version-%release

%description -n %lname
This package contains the libacl.so dynamic library which contains the
POSIX 1003.1e draft standard 17 functions for manipulating access
control lists.

%package -n libacl-devel
Summary:        Include Files and Libraries mandatory for Development
Group:          Development/Libraries/C and C++
# the .so file references libattr.so.x, so require libattr-devel
Requires:       %lname = %version
Requires:       glibc-devel
Requires:       libattr-devel
Provides:       acl-devel = %{version}
Obsoletes:      acl-devel < %{version}
# bug437293
%ifarch ppc64
Obsoletes:      libacl-devel-64bit
%endif
#

%description -n libacl-devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%setup -q -n acl-%version
%patch0 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

%build
export OPTIMIZER="$RPM_OPT_FLAGS -fPIC"
export DEBUG=-DNDEBUG
CFLAGS="$RPM_OPT_FLAGS"
%configure \
	--prefix=/ \
	--exec-prefix=/ \
	--sbindir=/bin \
	--libdir=/%{_lib} \
    --libexecdir=/%{_lib} \
	--disable-static \
	--with-pic
%{__make} %{?_smp_mflags}

%install
DIST_ROOT="$RPM_BUILD_ROOT"
DIST_INSTALL=`pwd`/install.manifest
DIST_INSTALL_DEV=`pwd`/install-dev.manifest
DIST_INSTALL_LIB=`pwd`/install-lib.manifest
export DIST_ROOT DIST_INSTALL DIST_INSTALL_DEV DIST_INSTALL_LIB
/usr/bin/make install DIST_MANIFEST="$DIST_INSTALL"
/usr/bin/make install-dev DIST_MANIFEST="$DIST_INSTALL_DEV"
/usr/bin/make install-lib DIST_MANIFEST="$DIST_INSTALL_LIB"
%{__mkdir_p} %{buildroot}%{_libdir}
%{__ln_s} -v /%{_lib}/$(readlink %{buildroot}/%{_lib}/lib%{name}.so) %{buildroot}%{_libdir}/lib%{name}.so
%{__rm} -v %{buildroot}/%{_lib}/lib%{name}.{la,so}
%find_lang %name

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -f %name.lang
%defattr(-,root,root)
%attr(755,root,root) %{_bindir}/chacl
%attr(755,root,root) %{_bindir}/getfacl
%attr(755,root,root) %{_bindir}/setfacl
%dir %attr(755,root,root) /usr/share/doc/packages/acl
%doc %attr(644,root,root) /usr/share/doc/packages/acl/CHANGES.gz
%doc %attr(644,root,root) /usr/share/doc/packages/acl/COPYING
%doc %attr(644,root,root) /usr/share/doc/packages/acl/COPYING.LGPL
%doc %attr(644,root,root) /usr/share/doc/packages/acl/PORTING
%doc %attr(644,root,root) /usr/share/doc/packages/acl/README
%doc %attr(644,root,root) %{_mandir}/man1/chacl.1.gz
%doc %attr(644,root,root) %{_mandir}/man1/getfacl.1.gz
%doc %attr(644,root,root) %{_mandir}/man1/setfacl.1.gz
%doc %attr(644,root,root) %{_mandir}/man5/acl.5.gz

%files -n libacl-devel
%defattr(-,root,root)
%dir %attr(755,root,root) %{_includedir}/acl
%attr(644,root,root) %{_includedir}/acl/libacl.h
%attr(644,root,root) %{_includedir}/sys/acl.h
%attr(755,root,root) %{_libdir}/libacl.so
%doc %attr(644,root,root) %{_mandir}/man3/acl_add_perm.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_calc_mask.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_check.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_clear_perms.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_cmp.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_copy_entry.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_copy_ext.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_copy_int.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_create_entry.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_delete_def_file.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_delete_entry.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_delete_perm.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_dup.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_entries.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_equiv_mode.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_error.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_extended_fd.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_extended_file.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_free.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_from_mode.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_from_text.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_entry.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_fd.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_file.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_perm.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_permset.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_qualifier.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_get_tag_type.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_init.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_set_fd.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_set_file.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_set_permset.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_set_qualifier.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_set_tag_type.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_size.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_to_any_text.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_to_text.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_valid.3.gz
%doc %attr(644,root,root) %{_mandir}/man3/acl_extended_file_nofollow.3.gz

%files -n %lname
%defattr(755,root,root,755)
/%{_lib}/libacl.so.1*

%changelog
* Fri Sep 25 2015 jeffm@suse.com
- Added important fixes since last release:
  * getfacl: Fix memory leak
  * getfacl: Fix minor resource leak
  * libacl: fix SIGSEGV of getfacl -e on overly long group name (bsc#945899)
  * libacl: Make sure that acl_from_text() always sets errno when it fails (bsc#945899)
  * read_acl_{comments,seq}: rename "line" to "lineno"
  * read_acl_{comments,seq}: switch to next_line
- Added patches:
  * getfacl-fix-memory-leak.patch
  * getfacl-fix-minor-resource-leak.patch
  * libacl-fix-sigsegv-of-getfacl-e-on-overly-long-group-name.patch
  * libacl-make-sure-that-acl_from_text-always-sets-errno-when-it-fails.patch
  * read_acl_-comments-seq-rename-line-to-lineno.patch
  * read_acl_-comments-seq-switch-to-next_line.patch
* Tue Jun 18 2013 coolo@suse.com
- remove gpg-offline calls from bootstrap package
* Sun Jun 16 2013 jengelh@inai.de
- Update to new upstream release 2.2.52
  * This release fixes a few build system issues that were found and
  merges in a tree walking bug fix.
- Remove acl-fiximplicit.patch (merged upstream),
  config-guess-sub-update.diff (no longer applies)
- Sync baselibs.conf with in-.spec obsoletes/provides.
* Tue Mar 19 2013 meissner@suse.com
- add gpg checking
* Fri Mar 15 2013 coolo@suse.com
- use source url
* Sat Feb  2 2013 dmueller@suse.com
- Add config-guess-sub-update.diff:
  update config.guess/sub to latest state for AArch64
* Wed Dec 26 2012 crrodriguez@opensuse.org
- Use OS byteswapping routines, application already Includes
  "endian.h" but then goes ahead defining ad-hoc equivalent
  functionality (0001-Use-OS-byteswapping-macros.patch)
* Wed May 30 2012 sweet_f_a@gmx.de
- remove useless automake deps
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Nov 30 2011 cfarrell@suse.com
- license update: GPL-2.0+;LGPL-2.1+
  SPDX format
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Sep 20 2011 crrodriguez@opensuse.org
- Fix provides/Obsoletes
* Fri Sep 16 2011 jengelh@medozas.de
- Implement shlib package (libacl1)
- Enable libacl-devel on all baselib arches
* Tue Apr 19 2011 bphilips@novell.com
- upgrade to 2.2.51
  - Test fixes
* Sat Apr 16 2011 bphilips@novell.com
- upgrade to 2.2.50
  - OPTIONS in man pages should be a section heading, not a subsection heading
  - Fix a typo in the setfacl man page
  - setfacl: Clarify that removing a non-existent acl entry is not an error
  - Prevent setfacl --restore from SIGSEGV on malformed restore file
  - setfacl: make sure that -R only calls stat(2) on symlinks when it needs to
  - libacl: fix potential null pointer dereference
  - setfacl: fix restore crash on malformed input
  - setfacl: print useful error from read_acl_comments
  - setfacl: changing owner and when S_ISUID should be set --restore fix
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Dec 12 2009 jengelh@medozas.de
- add baselibs.conf as a source
- adjust baselibs.conf for SPARC
* Wed Nov 25 2009 meissner@suse.de
- readded incorrectly removed libattr-devel requires in -devel
* Mon Oct 26 2009 meissner@suse.de
- fixed implicit strchr() usage.
* Sun Sep 27 2009 crrodriguez@suse.de
- do not package static libraries
- fix -devel package dependencies
* Sat Aug  1 2009 bphilips@novell.com
- Version bump to 2.2.48
  - Document the new flags comments
  - Include the S_ISUID, S_ISGID, S_ISVTX flags in the getfacl output, and restore them with "setfacl --restore=file".
  - Make sure that getfacl -R only calls stat(2) on symlinks when it needs to
  - Stop quoting nonprintable characters in the getfacl output
  - Avoid unnecessary but destructive chown calls
  - Clarify license notice
* Fri Feb 13 2009 bphilips@novell.com
- fix setfacl for long utf8 filenames (rh#183181)
  - Return error status on setfacl failures (rh#368451)
  - getfacl/setfacl should support shortcode flags (rh#204087)
* Thu Jan  8 2009 bphilips@novell.com
- Added a number of unit test improvements
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Fri Jul 11 2008 bphilips@suse.de
- Failure to recursively set/get ACLs on directories (bnc#404075)
- When invoked as ``setfacl -- ...'', setfacl segfaults (bnc#369425).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Sat Oct 27 2007 agruen@suse.de
- Don't exhaust the number of file descriptors in the path walking
  code, and make sure each directory is only visited once.
* Fri Oct 26 2007 agruen@suse.de
- A large jump to the current upstream version 2.2.45.
- Fix the upstream path walking code.
* Sat Mar 18 2006 agruen@suse.de
- Remove broken file /usr/lib[64]/libacl.la.
* Fri Mar 17 2006 agruen@suse.de
- Fix symlinks in the -devel package (149945, Nathan Scott).
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 mjancar@suse.cz
- update to 2.2.34
* Tue Sep  6 2005 coolo@suse.de
- Fixing devel dependencies (the libtool check chokes on the symlinks,
  but it still is right)
* Fri Aug 26 2005 agruen@suse.de
- Update to version 2.2.31: Integrate a patch we had separately;
  additional stdin error handling in setfacl.
* Fri Aug 19 2005 kukuk@suse.de
- Move devel files from / to /usr
- Don't generate filelist dynamic (fix broken attr statements)
* Mon Apr 25 2005 meissner@suse.de
- Use RPM_OPT_FLAGS.
* Mon Feb 21 2005 agruen@suse.de
- Update to version 2.2.30. Several fixes.
* Thu Nov 11 2004 coolo@suse.de
- use %%find_lang
* Wed Aug 25 2004 agruen@suse.de
- #43472: Fix processing of the X pseudo permission in setfacl:
  Must not modify the sequence of commands directly or else only
  the first file is processed correctly, and X is not evaluated
  for any other file. Add test case for X pseudo permission.
- Remove support for relative permission changes; this
  non-standard feature was disabled since a while already.
- Bump version number to 2.2.25.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Jan  1 2004 agruen@suse.de
- Update to version 2.2.21. Bug fix in directory tree walking
  code.
* Wed Oct 22 2003 kukuk@suse.de
- Fix provides for update case
* Thu Aug 28 2003 agruen@suse.de
- Fix a bug with error handling while walking directory trees.
* Wed Aug 27 2003 ro@suse.de
- fix patch depth in specfile
* Tue Aug 26 2003 agruen@suse.de
- Fix SIGSEGV if the quote function.
* Fri Aug 15 2003 agruen@suse.de
- Update to 2.2.15: Includes quoting of special characters in
  path and user names, and several minor fixes. (For details see
  doc/CHANGES in the tarball).
* Mon Jun 16 2003 ja@suse.cz
- File list fixed.
* Sun Apr  6 2003 agruen@suse.de
- Update to 2.2.7.
* Wed Feb 26 2003 agruen@suse.de
- Update to acl-2.2.3a, which has all our patches plus an
  additional malloc bug fix.
* Mon Feb 24 2003 agruen@suse.de
- Increment libattr library version to 1.1.0.
- Add symbol level versioning for libacl.
* Sat Feb  8 2003 agruen@suse.de
- Fix a long standing bug in acl_get_file() for Default ACLs (that
  probably was there from hour one), and another critical bug in
  the libacl entry pre-allocation patch (introduced on Jan 22).
* Tue Jan 28 2003 agruen@suse.de
- Fix inconsistent declarations for visibility("hidden") attributes
  ("config.h" was not always included).
- Fix a signedness warning in getfacl/user_group.c with a type
  cast.
* Wed Jan 22 2003 agruen@suse.de
- Update to acl-2.2.2
- Fix a memory leak in acl_init()
- Add memory pre-allocation support patch for libacl
- Add ACL copying functions patch
- Add visibility(hidden) patch that hides libacl internal functions
  from the outside.
- Let mls@suse.de add the following package alias in Autobuild
  for building packages against older releases:
  libacl-devel -> acl-devel [for <= 8.1]
* Tue Jan 21 2003 agruen@suse.de
- Remove (Prereq: /sbin/ldconfig) tag, and use %%run_ldconfig
  in %%post and %%postun instead.
- acl-devel was renamed to libacl-devel: add missing
  `Obsoletes: acl-devel' tag to libacl-devel.
* Sun Jan 19 2003 agruen@suse.de
- Fix a typo and add a clarification in the acl.5 manual page.
* Fri Dec 13 2002 schwab@suse.de
- Fix filelist generation.
* Fri Dec 13 2002 jderfina@suse.cz
- upgrading to version 2.1.1
- spliting acl to acl (binaries), libacl (libraries) and libacl-devel
  (development stuff). This spliting follows SGI's release.
* Thu Sep  5 2002 agruen@suse.de
- Update to 2.0.19 + additional corrections (see
  acl-2.0.19/doc/CHANGES).
* Thu Aug 15 2002 agruen@suse.de
- Remove the suse_update_config macro and the config.* stuff.
  (According to ro@suse.de this is not necessary.)
- Change the documentation path in builddefs.in instead of in
  configure.in.
- Update to version 2.0.17
* Thu Jun 20 2002 uli@suse.de
- fixed for lib64
* Thu Jun 20 2002 lmuelle@suse.de
- Remove DESTDIR patch, use DIST_ROOT of package instead
- Fix library location in the devel package
- Update to version 2.0.11
* Tue May  7 2002 sf@suse.de
- moved libs to %%{_lib} (they were in /lib _and_ /usr/lib before)
* Mon Feb 25 2002 ro@suse.de
- initial package (v2.0.0) (split from xfsprogs spec)
